#!/bin/sh

myHello() {
cat << __EOF__
####################################################################
## FreeBSD 4.3 telnetd Security Patching Script                   ##
##                                                                ##
## WARNING: This patching utility is only for FreeBSD 4.3-RELEASE ##
##          and FreeBSD 4.3-STABLE prior to 2001-07-27 with the   ##
##          crypto-telnet sources and KerberosIV installed.       ##
## ______________________________________________________________ ##
##                                                                ##
## FreeBSD-SA-01:49.telnetd / Security Advisory                   ##
## o Topic     : telnetd contains remote buffer overflow          ##
## o Category  : core                                             ##
## o Announced : 2001-07-23, Revised: 2001-07-27                  ##
## o Affects   : All releases of FreeBSD 3.x, 4.x prior to 4.4,   ##
##               FreeBSD 4.3-STABLE prior to the correction date  ##
## ______________________________________________________________ ##
##                                                                ##
##             Provided by OpenBIRD, Inc. http://www.openbird.com ##
####################################################################
__EOF__
printf "Press ENTER to check system environments..."
read x
echo ""
}

myExit() {
	echo "ERROR: $1"
	exit 1
}

myCheckReq() {
	printf "Checking $2... "
	if [ -f "$1" ]; then
		echo "AVAILABLE"
	elif [ -d "$1" ]; then
		echo "AVAILABLE"
	else
		echo "NOT AVAILABLE"
		myExit "Sorry, could not process. Please patch manually."
	fi
}

myHello

# check user
if [ "$USER" != "root" ]; then
	myExit "Run under ROOT permission."
fi

# check version
VER=`uname -r`
echo "Checking version... $VER"
if [ "$VER" != "4.3-RELEASE" ] && [ "$VER" != "4.3-STABLE" ]; then
	myExit "Sorry, this patch is only for 4.3-RELEASE and 4.3-STABLE." 
fi

# check requirements
myCheckReq "/usr/src/crypto/telnet/telnetd" "crypto distribution"
myCheckReq "/usr/lib/libkrb.a" "kerberosIV distribution"

printf "Press ENTER to apply patch..."
read x
echo ""

echo "Backing up telnetd to telnetd.orig..."
mv /usr/libexec/telnetd /usr/libexec/telnetd.orig
echo "Applying patch..."
cp -f ./telnetd /usr/libexec/telnetd
chmod 555 /usr/libexec/telnetd
chown root:wheel /usr/libexec/telnetd

echo "Patch succefully applied..."
ls -al /usr/libexec/telnetd
echo "DONE"
